<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<script src="https://embed.githubusercontent.com/view/geojson/benbalter/dc-wifi-social/master/bars.geojson"></script>',
        'width' => null,
        'height' => null,
        'ratio' => null
    ],
    'description' => 'A collaborative list of DC locations that serve up both Internet and Alcohol - benbalter/dc-wifi-social',
    'favicon' => 'https://github.githubassets.com/favicons/favicon.svg',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://avatars.githubusercontent.com/u/282759?s=400&v=4',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'GitHub',
    'providerUrl' => 'https://github.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'benbalter/dc-wifi-social',
    'url' => 'https://github.com/benbalter/dc-wifi-social/blob/master/bars.geojson',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
